Project Contributors
====================

The following people have made contributions to the project (in alphabetical
order by last name) and are considered "The icepyx Developers".
Thanks goes to these wonderful people (`emoji key <https://allcontributors.org/docs/en/emoji-key>`_):

* `Nicole Abib <https://github.com/nabib/>`_ - University of Oregon
* `Anthony Arendt <https://github.com/aaarendt/>`_ - University of Washington
* `Shashank Bhushan <https://github.com/ShashankBice>`_ - University of Washington
* `Alessandro Di Bella <https://github.com/alexdibella>`_ - Technical University of Denmark
* `Raphael Hagen <https://github.com/norlandrhagen>`_ - University of Washington
* `Scott Henderson <https://github.com/scottyhq>`_ - University of Washington
* `Thomas Johnson <https://github.com/loudTom>`_ - University College London
* `Zheng Liu <https://github.com/liuzheng-arctic>`_ - University of Washington
* `Ted Maksym <https://github.com/tedmaksym>`_ - Woods Hole Oceanographic Institution
* `Joachim Meyer <https://github.com/jomey>`_ - University of Utah
* `Fernando Perez <https://github.com/fperez>`_ - University of California, Berkeley
* `Romina Piunno <https://github.com/RomiP>`_ - University of Toronto
* `Facundo Sapienza <https://github.com/facusapienza21>`_ - University of California, Berkeley
* `David Shean <https://github.com/dshean>`_ - University of Washington
* `Ben Smith <https://github.com/smithb>`_ - University of Washington
* `Trey Stafford <https://github.com/trey-stafford>`_ - NSIDC, University of Colorado
* `Amy Steiker <https://github.com/asteiker>`_ - NSIDC, University of Colorado
* `Tyler Sutterley <https://github.com/tsutterley>`_ - University of Washington
* `Anna Valentine <https://github.com/annavalentine>`_ - Colorado School of Mines
* `Bruce Wallin <https://github.com/wallinb>`_ - NSIDC, University of Colorado
* `Molly Wieringa <https://github.com/mollymwieringa>`_ - University of Washington
* `Bidhyananda Yadav <https://github.com/bidhya>`_ - Ohio State University


.. raw:: html

    <!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
    <!-- prettier-ignore-start -->
    <!-- markdownlint-disable -->
    <table>
      <tr>
        <td align="center"><a href="https://github.com/JessicaS11"><img src="https://avatars.githubusercontent.com/u/11756442?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jessica</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3AJessicaS11" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=JessicaS11" title="Code">💻</a> <a href="#content-JessicaS11" title="Content">🖋</a> <a href="https://github.com/icesat2py/icepyx/commits?author=JessicaS11" title="Documentation">📖</a> <a href="#design-JessicaS11" title="Design">🎨</a> <a href="#example-JessicaS11" title="Examples">💡</a> <a href="#ideas-JessicaS11" title="Ideas, Planning, & Feedback">🤔</a> <a href="#maintenance-JessicaS11" title="Maintenance">🚧</a> <a href="#mentoring-JessicaS11" title="Mentoring">🧑‍🏫</a> <a href="#projectManagement-JessicaS11" title="Project Management">📆</a> <a href="#question-JessicaS11" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3AJessicaS11" title="Reviewed Pull Requests">👀</a></td>
        <td align="center"><a href="http://bisson.work"><img src="https://avatars.githubusercontent.com/u/48059682?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kelsey Bisson</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Akelseybisson" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=kelseybisson" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=kelseybisson" title="Documentation">📖</a> <a href="#ideas-kelseybisson" title="Ideas, Planning, & Feedback">🤔</a> <a href="#example-kelseybisson" title="Examples">💡</a> <a href="#ideas-kelseybisson" title="Ideas, Planning, & Feedback">🤔</a> <a href="#mentoring-kelseybisson" title="Mentoring">🧑‍🏫</a> <a href="#question-kelseybisson" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Akelseybisson" title="Reviewed Pull Requests">👀</a> <a href="#tutorial-kelseybisson" title="Tutorials">✅</a></td>
        <td align="center"><a href="https://www.linkedin.com/in/sarah-hall-902a9b150/"><img src="https://avatars.githubusercontent.com/u/51332703?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Sarah Hall</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Asjh1024" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=sjh1024" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=sjh1024" title="Documentation">📖</a> <a href="#maintenance-sjh1024" title="Maintenance">🚧</a> <a href="https://github.com/icesat2py/icepyx/commits?author=sjh1024" title="Tests">⚠️</a></td>
        <td align="center"><a href="https://github.com/zachghiaccio"><img src="https://avatars.githubusercontent.com/u/48361714?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Zach Fair</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Azachghiaccio" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/commits?author=zachghiaccio" title="Code">💻</a> <a href="https://github.com/icesat2py/icepyx/commits?author=zachghiaccio" title="Documentation">📖</a> <a href="#ideas-zachghiaccio" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-zachghiaccio" title="Answering Questions">💬</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Azachghiaccio" title="Reviewed Pull Requests">👀</a> <a href="#tutorial-zachghiaccio" title="Tutorials">✅</a></td>
        <td align="center"><a href="https://github.com/nitin-ravinder"><img src="https://avatars.githubusercontent.com/u/86551841?v=4?s=100" width="100px;" alt=""/><br /><sub><b>nitin-ravinder</b></sub></a><br /><a href="https://github.com/icesat2py/icepyx/issues?q=author%3Anitin-ravinder" title="Bug reports">🐛</a> <a href="https://github.com/icesat2py/icepyx/pulls?q=is%3Apr+reviewed-by%3Anitin-ravinder" title="Reviewed Pull Requests">👀</a></td>
      </tr>
    </table>

    <!-- markdownlint-restore -->
    <!-- prettier-ignore-end -->

    <!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the `all-contributors <https://github.com/all-contributors/all-contributors>`_ specification. Contributions of any kind welcome!
